#--------------------------------
# XCircuit Resource setup for TCL
#--------------------------------

option add *xcircuit.width 1200
option add *xcircuit.height 930
option add *xcircuit*activeBackground #a07650
option add *xcircuit*foreground #a07650
option add *xcircuit*activeForeground beige
option add *xcircuit*font -*-times-medium-r-normal--12-*

option add *xcircuit1.width 900
option add *xcircuit1.height 700
option add *xcircuit1*activeBackground #a07650
option add *xcircuit1*foreground #a07650
option add *xcircuit1*activeForeground beige
option add *xcircuit1*font -*-times-medium-r-normal--12-*

option add *xcircuit2.width 700
option add *xcircuit2.height 500
option add *xcircuit2*activeBackground #a07650
option add *xcircuit2*foreground #a07650
option add *xcircuit2*activeForeground beige
option add *xcircuit2*font -*-times-medium-r-normal--12-*

option add *menubar.filebutton*background beige
option add *menubar.editbutton*background beige
option add *menubar.textbutton*background beige
option add *menubar.optionsbutton*background beige
option add *menubar.windowbutton*background beige
option add *menubar.netlistbutton*background beige
option add *menubar*font -*-times-bold-r-normal--12-*

option add *librarymenu*activeBackground #805630
option add *librarymenu*foreground #805630
option add *librarymenu*activeForeground beige
option add *librarymenu*font -*-times-medium-r-normal--12-*
option add *librarymenu*background beige

option add *pagemenu*activeBackground #805630
option add *pagemenu*foreground #805630
option add *pagemenu*activeForeground beige
option add *pagemenu*font -*-times-medium-r-normal--12-*
option add *pagemenu*background beige

option add *filelist*activeBackground #805630
option add *filelist*foreground #805630
option add *filelist*background white
option add *filelist*activeForeground beige
option add *filelist*font -*-times-medium-r-normal--12-*
option add *filelist*txt*font -*-courier-medium-r-normal--12-*

option add *output*activeBackground #805630
option add *output*foreground #805630
option add *output*backtround white
option add *output*activeForeground beige
option add *output*font -*-times-medium-r-normal--12-*
option add *output*txt*font -*-courier-medium-r-normal--12-*

option add *output.textent.butp.psmenu*background beige
option add *output.textent.txtf.sizb.sizemenu*background beige
option add *output.textent.buto.orientmenu*background beige

option add *help*activeBackground #805630
option add *help*foreground #805630
option add *help*background white
option add *help*activeForeground beige
option add *help*font -*-times-medium-r-normal--12-*
option add *help*txt*font -*-times-courier-r-normal--12-*

option add *dialog*activeBackground #805630
option add *dialog*foreground #805630
option add *dialog*background white
option add *dialog*activeForeground beige
option add *dialog*font -*-times-medium-r-normal--12-*
option add *dialog*txt*font -*-courier-medium-r-normal--12-*

# End of Resource configuration file.
